AccessControlRequestHeaders

Struct AccessControlRequestHeaders 

pub struct AccessControlRequestHeaders(pub HeaderFieldNamesSet);
The Access-Control-Request-Headers request header

You can use this as a rocket Request Guard to ensure that the header is passed in correctly.

Tuple Fields

0: HeaderFieldNamesSet

Implementations

Source

impl AccessControlRequestHeaders

pub fn from_request_sync(request: &Request<'_>) -> Outcome<Self, Error>

Derives an instance of Self from the incoming request metadata.

If the derivation is successful, an outcome of Success is returned. If the derivation fails in an unrecoverable fashion, Failure is returned. Forward is returned to indicate that the request should be forwarded to other matching routes, if any.